@@ -37,7 +37,7 @@ import binascii
 class ssrlbin:
     global reloadps
 
-    def __init__(self,fn,master):
+    def __init__(self,fn,master,ieee=0):
         global reloadps
         #make dictionary for columns
         fid=open(fn,"rb")
@@ -114,7 +114,11 @@ class ssrlbin:
             j=0
             while j<ncols:
                 buf=fid.read(4)
-                new=fromstring(buf[2]+buf[3]+buf[0]+buf[1],Float32)/4  #2301
+                if not ieee:
+                    new=fromstring(buf[2]+buf[3]+buf[0]+buf[1],Float32)/4  #2301
+                else:
+                    #new=fromstring(buf[0]+buf[1]+buf[2]+buf[3],Float32)/4
+                    new=unpack('f',buf)[0]
                 ind=j+ncols*i
                 put(d,ind,new)
                 j=j+1
@@ -151,6 +155,8 @@ class ssrlbin:
                     raise ValueError, ""
             except:
                 reloadps=[]
+                rsel='Ge'
+                select=''
                 if ffl!=0 and ffst!=0:
                     #file has BOTH Lytle and Ge channels
                     #ask which...
@@ -166,27 +172,27 @@ class ssrlbin:
                         detind.update({'ifst':ffl})
                         detind.update({'ife':ffl})
                     #SCA selection for Ge
-                    if rsel=='Ge' and ffscax[0][0]!=0:
-                        scadialog=Pmw.Dialog(parent=master,title="SCA Selection",buttons=('OK',))
-                        scaselbox=Pmw.RadioSelect(parent=scadialog.interior(),labelpos='n',label_text="Please select SCA channel to load")
-                        sbuts=('SCA1','SCA2')
-                        if ffscax[1][0]!=0:sbuts=('SCA1','SCA2','SCA3')
-                        for sb in sbuts:
-                            scaselbox.add(sb)
-                        scaselbox.pack(side=TOP,fill='both',expand=1,padx=5,pady=5)
-                        scaselect=scadialog.activate()
-                        ssel=scaselbox.getvalue()
-                        if ssel=='SCA2':
-                            detind.update({'ifst':ffscax[0][0]})
-                            detind.update({'ife':ffscax[0][1]})
-                        if ssel=='SCA3':
-                            detind.update({'ifst':ffscax[1][0]})
-                            detind.update({'ife':ffscax[1][1]})                        
-                    if select=='Apply All':
-                        try:
-                            reloadps=[self.type,rsel,ssel]
-                        except:
-                            reloadps=[self.type,rsel,'SCA1']
+                if rsel=='Ge' and ffscax[0][0]!=0:
+                    scadialog=Pmw.Dialog(parent=master,title="SCA Selection",buttons=('OK',))
+                    scaselbox=Pmw.RadioSelect(parent=scadialog.interior(),labelpos='n',label_text="Please select SCA channel to load")
+                    sbuts=('SCA1','SCA2')
+                    if ffscax[1][0]!=0:sbuts=('SCA1','SCA2','SCA3')
+                    for sb in sbuts:
+                        scaselbox.add(sb)
+                    scaselbox.pack(side=TOP,fill='both',expand=1,padx=5,pady=5)
+                    scaselect=scadialog.activate()
+                    ssel=scaselbox.getvalue()
+                    if ssel=='SCA2':
+                        detind.update({'ifst':ffscax[0][0]})
+                        detind.update({'ife':ffscax[0][1]})
+                    if ssel=='SCA3':
+                        detind.update({'ifst':ffscax[1][0]})
+                        detind.update({'ife':ffscax[1][1]})                        
+                if select=='Apply All':
+                    try:
+                        reloadps=[self.type,rsel,ssel]
+                    except:
+                        reloadps=[self.type,rsel,'SCA1']             
             if detind['ifst']==detind['ife']:
                 #lytle/single channel
                 self.iF=d[:,detind['ifst']]
@@ -321,6 +327,8 @@ class ssrlascii:
                     raise ValueError, ""
             except:
                 reloadps=[]
+                rsel='Ge'
+                select=''                
                 if ffl!=0 and ffst!=0:
                     #file has BOTH Lytle and Ge channels
                     #ask which...
@@ -335,28 +343,28 @@ class ssrlascii:
                     if rsel=='Lytle' or rsel==None:
                         detind.update({'ifst':ffl})
                         detind.update({'ife':ffl})
-                    #SCA selection for Ge
-                    if rsel=='Ge' and ffscax[0][0]!=0:
-                        scadialog=Pmw.Dialog(parent=master,title="SCA Selection",buttons=('OK',))
-                        scaselbox=Pmw.RadioSelect(parent=scadialog.interior(),labelpos='n',label_text="Please select SCA channel to load")
-                        sbuts=('SCA1','SCA2')
-                        if ffscax[1][0]!=0:sbuts=('SCA1','SCA2','SCA3')
-                        for sb in sbuts:
-                            scaselbox.add(sb)
-                        scaselbox.pack(side=TOP,fill='both',expand=1,padx=5,pady=5)
-                        scaselect=scadialog.activate()
-                        ssel=scaselbox.getvalue()
-                        if ssel=='SCA2':
-                            detind.update({'ifst':ffscax[0][0]})
-                            detind.update({'ife':ffscax[0][1]})
-                        if ssel=='SCA3':
-                            detind.update({'ifst':ffscax[1][0]})
-                            detind.update({'ife':ffscax[1][1]})  
-                    if select=='Apply All':
-                        try:
-                            reloadps=[self.type,rsel,ssel]
-                        except:
-                            reloadps=[self.type,rsel,'SCA1']
+                #SCA selection for Ge
+                if rsel=='Ge' and ffscax[0][0]!=0:
+                    scadialog=Pmw.Dialog(parent=master,title="SCA Selection",buttons=('OK',))
+                    scaselbox=Pmw.RadioSelect(parent=scadialog.interior(),labelpos='n',label_text="Please select SCA channel to load")
+                    sbuts=('SCA1','SCA2')
+                    if ffscax[1][0]!=0:sbuts=('SCA1','SCA2','SCA3')
+                    for sb in sbuts:
+                        scaselbox.add(sb)
+                    scaselbox.pack(side=TOP,fill='both',expand=1,padx=5,pady=5)
+                    scaselect=scadialog.activate()
+                    ssel=scaselbox.getvalue()
+                    if ssel=='SCA2':
+                        detind.update({'ifst':ffscax[0][0]})
+                        detind.update({'ife':ffscax[0][1]})
+                    if ssel=='SCA3':
+                        detind.update({'ifst':ffscax[1][0]})
+                        detind.update({'ife':ffscax[1][1]})  
+                if select=='Apply All':
+                    try:
+                        reloadps=[self.type,rsel,ssel]
+                    except:
+                        reloadps=[self.type,rsel,'SCA1']
             if detind['ifst']==detind['ife']:
                 #lytle/single channel
                 self.iF=d[:,detind['ifst']]
@@ -643,8 +651,10 @@ class gsecarsascii:
                         last=lp[len(lp)-1]
                         if len(last)>2: reg=last[len(last)-2:len(last)]
                         if reg[0]=='R' and len(reg)==2 and reg not in reglist:
-                            rlab=lp[4]+' '+lp[5]
+                            #rlab=lp[4]+' '+lp[5]
+                            rlab=line[rfind(line,'{'):rfind(line,'}')]
                             rlab=rstrip(replace(rlab,'}',' '))
+                            rlab=rstrip(replace(rlab,'{',' '))
                             roibuts.append(reg+':'+rlab)
                             reglist.append(reg)
                         if lower(type2)=='{lyt' or lower(type2)=='{mu}' or lower(type2)=='{if}':
@@ -705,7 +715,9 @@ class gsecarsascii:
                             chandef[4].append(lp[1])
                         if lower(type2)=='{lyt' or type2=='{mu}' or lower(type2)=='{if}':
                             chandef[7].append(lp[1])
-                        if lower(type2)=='{mca' and reg==reg1:
+                        if (lower(type2)=='{mca' and reg==reg1): 
+                            chandef[5].append(lp[1])
+                        elif (len(lp)>6 and rfind(lp[6],'mca') and reg==reg1):
                             chandef[5].append(lp[1])
                 if readstate==3: #read data lines
                     parsed=split(line)
@@ -1479,7 +1491,10 @@ def XASget(fn,master):
             e=array((starte,ende))
             return dndquick(fn,e,edge)
     elif count(buf,'SRL -')==1:
-        return ssrlbin(fn,master)
+        if float(buf.split()[-1])<2:
+            return ssrlbin(fn,master)
+        else:
+            return ssrlbin(fn,master,ieee=1)
     elif count(buf,'SRL  ')==1:
         return ssrlascii(fn,master)
     elif binascii.b2a_hex(buf[0:6])=='000000010000':
